==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/sax/GnomeSAXParserFactory.h <==
// public class gnu.xml.libxmlj.sax.GnomeSAXParserFactory

// class file dependencies
// @dep_class f05eee70dc721f5f gnu_xml_libxmlj_sax_GnomeSAXParserFactory
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 86e754aa89cca8e1 javax_xml_parsers_SAXParserFactory

// header file dependencies
// @dep_header javax_xml_parsers_SAXParserFactory

#include "javax/xml/parsers/SAXParserFactory.h"

#ifndef _JC_gnu_xml_libxmlj_sax_GnomeSAXParserFactory_H_
#define _JC_gnu_xml_libxmlj_sax_GnomeSAXParserFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_javax_xml_parsers_SAXParser$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_refs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_nonrefs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$refs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$refs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$nonrefs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object;

typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vmethods	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtable	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtable;
typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *);

// Virtual methods
extern jboolean _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method$getFeature$1f81e149fe4bca3b(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *, struct _jc_java_lang_String$object *);
extern struct _jc_javax_xml_parsers_SAXParser$object *_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method$newSAXParser$f0f8ffdd5540228d(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *);
extern void _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method$setFeature$907897e626165cee(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *, struct _jc_java_lang_String$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method_info$getFeature$1f81e149fe4bca3b;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method_info$newSAXParser$f0f8ffdd5540228d;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method_info$setFeature$907897e626165cee;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vmethods {
	jboolean	(*getFeature$1f81e149fe4bca3b)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *, struct _jc_java_lang_String$object *);
	struct _jc_javax_xml_parsers_SAXParser$object	*(*newSAXParser$f0f8ffdd5540228d)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *);
	void	(*setFeature$907897e626165cee)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *, struct _jc_java_lang_String$object *, jboolean);
};

// Vtable
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_SAXParserFactory$vmethods	javax_xml_parsers_SAXParserFactory;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vmethods	gnu_xml_libxmlj_sax_GnomeSAXParserFactory;
};

// Vtype
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_refs {
	struct _jc_object	*features;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$refs {
    _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_refs	gnu_xml_libxmlj_sax_GnomeSAXParserFactory;
    _jc_javax_xml_parsers_SAXParserFactory$sub_refs	javax_xml_parsers_SAXParserFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_SAXParserFactory$sub_nonrefs	javax_xml_parsers_SAXParserFactory;
    _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_nonrefs	gnu_xml_libxmlj_sax_GnomeSAXParserFactory;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object {
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype	*vtype;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_sax_GnomeSAXParserFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$class_object;

#endif	/* _JC_gnu_xml_libxmlj_sax_GnomeSAXParserFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/sax/GnomeSAXParserFactory.h <==
// public class gnu.xml.libxmlj.sax.GnomeSAXParserFactory

// class file dependencies
// @dep_class f05eee70dc721f5f gnu_xml_libxmlj_sax_GnomeSAXParserFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 86e754aa89cca8e1 javax_xml_parsers_SAXParserFactory

// header file dependencies
// @dep_header javax_xml_parsers_SAXParserFactory

#include "javax/xml/parsers/SAXParserFactory.h"

#ifndef _JC_gnu_xml_libxmlj_sax_GnomeSAXParserFactory_H_
#define _JC_gnu_xml_libxmlj_sax_GnomeSAXParserFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_javax_xml_parsers_SAXParser$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_refs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_nonrefs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$refs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$refs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$nonrefs	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object;

typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vmethods	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtable	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtable;
typedef const struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method$getFeature$1f81e149fe4bca3b(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_parsers_SAXParser$object *_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method$newSAXParser$f0f8ffdd5540228d(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method$setFeature$907897e626165cee(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method_info$getFeature$1f81e149fe4bca3b;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method_info$newSAXParser$f0f8ffdd5540228d;
extern _jc_method _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$method_info$setFeature$907897e626165cee;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vmethods {
	jboolean	(*getFeature$1f81e149fe4bca3b)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_parsers_SAXParser$object	*(*newSAXParser$f0f8ffdd5540228d)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *) _JC_JCNI_ATTR;
	void	(*setFeature$907897e626165cee)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_SAXParserFactory$vmethods	javax_xml_parsers_SAXParserFactory;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vmethods	gnu_xml_libxmlj_sax_GnomeSAXParserFactory;
};

// Vtype
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_refs {
	struct _jc_object	*features;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$refs {
    _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_refs	gnu_xml_libxmlj_sax_GnomeSAXParserFactory;
    _jc_javax_xml_parsers_SAXParserFactory$sub_refs	javax_xml_parsers_SAXParserFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_SAXParserFactory$sub_nonrefs	javax_xml_parsers_SAXParserFactory;
    _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$sub_nonrefs	gnu_xml_libxmlj_sax_GnomeSAXParserFactory;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$object {
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype	*vtype;
	_jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$vtype _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_sax_GnomeSAXParserFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_sax_GnomeSAXParserFactory$class_object;

#endif	/* _JC_gnu_xml_libxmlj_sax_GnomeSAXParserFactory_H_ */
